import click
from click.decorators import pass_context
from flask.cli import with_appcontext
from os import environ

from flaschengeist import logger
from flaschengeist.controller import pluginController
from werkzeug.exceptions import NotFound
import traceback


@click.group()
def docker():
    pass


@docker.command()
@with_appcontext
@pass_context
def setup(ctx):
    """Setup flaschengesit in docker container"""
    click.echo("Setup docker")

    plugins = environ.get("FG_ENABLE_PLUGINS")

    if not plugins:
        click.secho("no evironment variable is set for 'FG_ENABLE_PLUGINS'", fg="yellow")
        click.secho("set 'FG_ENABLE_PLUGINS' to 'auth_ldap', 'mail', 'balance', 'pricelist_old', 'events'")
        plugins = ("auth_ldap", "mail", "pricelist_old", "events", "balance")
    else:
        plugins = plugins.split(" ")

    print(plugins)

    for name in plugins:
        click.echo(f"Installing {name}{'.'*(20-len(name))}", nl=False)
        try:
            pluginController.install_plugin(name)
        except Exception as e:
            click.secho(" failed", fg="red")
            if logger.getEffectiveLevel() > 10:
                ctx.fail(f"[{e.__class__.__name__}] {e}")
            else:
                ctx.fail(traceback.format_exc())
        else:
            click.secho(" ok", fg="green")

    for name in plugins:
        click.echo(f"Enabling {name}{'.'*(20-len(name))}", nl=False)
        try:
            pluginController.enable_plugin(name)
            click.secho(" ok", fg="green")
        except NotFound:
            click.secho(" not installed / not found", fg="red")
