import click
from importlib.metadata import entry_points


@click.command()
@click.option("--output", "-o", help="Output file, default is stdout", type=click.Path())
@click.option("--namespace", "-n", help="TS namespace for the interfaces", type=str, show_default=True)
@click.option("--plugin", "-p", help="Also export types for a plugin (even if disabled)", multiple=True, type=str)
@click.option("--no-core", help="Skip models / types from flaschengeist core", is_flag=True)
def export(namespace, output, no_core, plugin):
    from flaschengeist import logger, models
    from flaschengeist.cli.InterfaceGenerator import InterfaceGenerator

    gen = InterfaceGenerator(namespace, output, logger)
    if not no_core:
        gen.run(models)
    if plugin:
        for entry_point in entry_points(group="flaschengeist.plugins"):
            if len(plugin) == 0 or entry_point.name in plugin:
                try:
                    plugin = entry_point.load()
                    gen.run(plugin.models)
                except:
                    logger.error(
                        f"Plugin {entry_point.name} could not be loaded due to an error.",
                        exc_info=True,
                    )
                    continue
    gen.write()
